@@ -1,9 +1,9 @@
+"""Demo extractor that returns nothing."""
+
 from io import BytesIO
-from typing import Dict, List, Optional
+from typing import List
 
-import yara
-
-from maco import extractor, model
+from maco import extractor, yara
 
 
 class Nothing(extractor.Extractor):
@@ -23,8 +23,12 @@ class Nothing(extractor.Extractor):
         }
         """
 
-    def run(
-        self, stream: BytesIO, matches: List[yara.Match]
-    ) -> Optional[model.ExtractorModel]:
+    def run(self, stream: BytesIO, matches: List[yara.Match]):
+        """Run the analysis process.
+
+        Args:
+            stream (BytesIO): file object from disk/network/memory.
+            matches (List[yara.Match]): yara rule matches
+        """
         # return config model formatted results
         return
