@@ -1,4 +1,5 @@
 """CLI example of how extractors can be executed."""
+
 import argparse
 import base64
 import binascii
@@ -8,7 +9,8 @@ import json
 import logging
 import os
 import sys
-from typing import BinaryIO, List
+from importlib.metadata import version
+from typing import BinaryIO, List, Tuple
 
 import cart
 
@@ -26,7 +28,20 @@ def process_file(
     force: bool,
     include_base64: bool,
 ):
-    """Process a filestream with the extractors and rules."""
+    """Process a filestream with the extractors and rules.
+
+    Args:
+        collected (collector.Collector): a Collector instance
+        path_file (str): path to sample to be analyzed
+        stream (BinaryIO): binary stream to be analyzed
+        pretty (bool): Pretty print the JSON output
+        force (bool): Run all extractors regardless of YARA rule match
+        include_base64 (bool): include base64'd data in output
+
+    Returns:
+        (dict): The output from the extractors analyzing the sample
+
+    """
     unneutered = io.BytesIO()
     try:
         cart.unpack_stream(stream, unneutered)
@@ -55,11 +70,9 @@ def process_file(
     ret = {}
     for extractor_name, hits in runs.items():
         # run and store results for extractor
-        logger.info(
-            f"run {extractor_name} extractor from rules {[x.rule for x in hits]}"
-        )
+        logger.info(f"run {extractor_name} extractor from rules {[x.rule for x in hits]}")
         try:
-            resp = collected.extract(stream, hits, extractor_name)
+            resp = collected.extract(stream, extractor_name)
         except Exception as e:
             logger.exception(f"extractor error with {path_file} ({e})")
             resp = None
@@ -70,9 +83,7 @@ def process_file(
                 # number of bytes in the binary
                 row["size"] = len(row["data"])
                 # small sample of first part of binary
-                row["hex_sample"] = (
-                    binascii.hexlify(row["data"][:32]).decode("utf8").upper()
-                )
+                row["hex_sample"] = binascii.hexlify(row["data"][:32]).decode("utf8").upper()
                 if include_base64:
                     # this can be large
                     row["base64"] = base64.b64encode(row["data"]).decode("utf8")
@@ -94,20 +105,27 @@ def process_filesystem(
     pretty: bool,
     force: bool,
     include_base64: bool,
-):
+    create_venv: bool = False,
+    skip_install: bool = False,
+) -> Tuple[int, int, int]:
+    """Process filesystem with extractors and print results of extraction.
+
+    Returns:
+        (Tuple[int, int, int]): Total number of analysed files, yara hits and successful maco extractions.
+    """
     if force:
-        logger.warning(
-            "force execute will cause errors if an extractor "
-            "requires a yara rule hit during execution"
-        )
-    collected = collector.Collector(path_extractors, include=include, exclude=exclude)
+        logger.warning("force execute will cause errors if an extractor requires a yara rule hit during execution")
+    collected = collector.Collector(
+        path_extractors, include=include, exclude=exclude, create_venv=create_venv, skip_install=skip_install
+    )
 
     logger.info(f"extractors loaded: {[x for x in collected.extractors.keys()]}\n")
     for _, extractor in collected.extractors.items():
+        extractor_meta = extractor["metadata"]
         logger.info(
-            f"{extractor.family} by {extractor.author}"
-            f" {extractor.last_modified} {extractor.sharing}"
-            f"\n{extractor.__doc__}\n"
+            f"{extractor_meta['family']} by {extractor_meta['author']}"
+            f" {extractor_meta['last_modified']} {extractor_meta['sharing']}"
+            f"\n{extractor_meta['description']}\n"
         )
 
     num_analysed = 0
@@ -123,10 +141,15 @@ def process_filesystem(
         logger.error(f"not file or folder: {path_samples}")
         exit(2)
     try:
-        for path, dirs, files in walker:
+        base_directory = os.path.abspath(path_samples)
+        for path, _, files in walker:
             for file in files:
                 num_analysed += 1
-                path_file = os.path.join(path, file)
+                path_file = os.path.abspath(os.path.join(path, file))
+                if not path_file.startswith(base_directory):
+                    logger.error(f"Attempted path traversal detected: {path_file}")
+                    continue
+
                 try:
                     with open(path_file, "rb") as stream:
                         resp = process_file(
@@ -148,12 +171,12 @@ def process_filesystem(
         raise
     finally:
         logger.info("")
-        logger.info(
-            f"{num_analysed} analysed, {num_hits} hits, {num_extracted} extracted"
-        )
+        logger.info(f"{num_analysed} analysed, {num_hits} hits, {num_extracted} extracted")
+    return num_analysed, num_hits, num_extracted
 
 
 def main():
+    """Main block for CLI."""
     parser = argparse.ArgumentParser(description="Run extractors over samples.")
     parser.add_argument("extractors", type=str, help="path to extractors")
     parser.add_argument("samples", type=str, help="path to samples")
@@ -164,25 +187,41 @@ def main():
         default=0,
         help="print debug logging. -v extractor info, -vv extractor debug, -vvv cli debug",
     )
-    parser.add_argument(
-        "--pretty", action="store_true", help="pretty print json output"
-    )
+    parser.add_argument("--pretty", action="store_true", help="pretty print json output")
     parser.add_argument(
         "--base64",
         action="store_true",
-        help="Include base64 encoded binary data in output (can be large, consider printing to file rather than console)",
+        help="Include base64 encoded binary data in output "
+        "(can be large, consider printing to file rather than console)",
     )
     parser.add_argument("--logfile", type=str, help="file to log output")
     parser.add_argument("--include", type=str, help="comma separated extractors to run")
-    parser.add_argument(
-        "--exclude", type=str, help="comma separated extractors to not run"
-    )
+    parser.add_argument("--exclude", type=str, help="comma separated extractors to not run")
     parser.add_argument(
         "-f",
         "--force",
         action="store_true",
         help="ignore yara rules and execute all extractors",
     )
+    parser.add_argument(
+        "--create_venv",
+        action="store_true",
+        help="Creates venvs for every requirements.txt found (only applies when extractor path is a directory). "
+        "This runs much slower than the alternative but may be necessary "
+        "when there are many extractors with conflicting dependencies.",
+    )
+    parser.add_argument(
+        "--force_install",
+        action="store_true",
+        help="Force installation of Python dependencies for extractors (in both host and virtual environments).",
+    )
+    parser.add_argument(
+        "--version",
+        action="version",
+        version=f"version: {version('maco')}",
+        help="Show version of MACO",
+    )
+
     args = parser.parse_args()
     inc = args.include.split(",") if args.include else []
     exc = args.exclude.split(",") if args.exclude else []
@@ -205,8 +244,7 @@ def main():
     ch = logging.StreamHandler(sys.stdout)
     ch.setLevel(logging.DEBUG)
     formatter = logging.Formatter(
-        fmt="%(asctime)s, [%(levelname)s] %(module)s.%(funcName)s: %(message)s",
-        datefmt="%Y-%m-%d (%H:%M:%S)"
+        fmt="%(asctime)s, [%(levelname)s] %(module)s.%(funcName)s: %(message)s", datefmt="%Y-%m-%d (%H:%M:%S)"
     )
     ch.setFormatter(formatter)
     logger_ex.addHandler(ch)
@@ -228,6 +266,8 @@ def main():
         pretty=args.pretty,
         force=args.force,
         include_base64=args.base64,
+        create_venv=args.create_venv,
+        skip_install=not args.force_install,
     )
 
 
