@@ -1,9 +1,9 @@
+"""Basic longer extractor."""
+
 from io import BytesIO
-from typing import List, Optional
+from typing import List
 
-import yara
-
-from maco import extractor, model
+from maco import extractor, model, yara
 
 
 class BasicLonger(extractor.Extractor):
@@ -23,9 +23,12 @@ class BasicLonger(extractor.Extractor):
         }
         """
 
-    def run(
-        self, stream: BytesIO, matches: List[yara.Match]
-    ) -> Optional[model.ExtractorModel]:
+    def run(self, stream: BytesIO, matches: List[yara.Match]) -> model.ExtractorModel:
+        """Run the extractor.
+
+        Returns:
+            (model.ExtractorModel): Results from extractor
+        """
         # use a custom model that inherits from ExtractorModel
         # this model defines what can go in the 'other' dict
         tmp = model.ExtractorModel(family="basic_longer")
