@@ -1,12 +1,16 @@
-import unittest
+"""Extractor testing."""
 
-import yara
+import unittest
 
 from maco import extractor
 
 
 class TestExtractor(unittest.TestCase):
+    """Test extractor."""
+
     def test_bad(self):
+        """Test bad extractor."""
+
         class Tmp(extractor.Extractor):
             family = "smell_ya_later"
             author = "me"
@@ -36,14 +40,14 @@ class TestExtractor(unittest.TestCase):
 
         class Tmp1(Tmp):
             yara_rule = """
-                rule BadName
+                rule DifferentName
                 {
                     condition:
                         true
                 }
             """
 
-        self.assertRaises(extractor.InvalidExtractor, Tmp1)
+        Tmp1()
 
         class Tmp1(Tmp):
             yara_rule = """
@@ -52,11 +56,11 @@ class TestExtractor(unittest.TestCase):
                     condition:
                         true
                 }
-                rule BadName
+                rule OtherName
                 {
                     condition:
                         true
                 }
             """
 
-        self.assertRaises(extractor.InvalidExtractor, Tmp1)
+        Tmp1()
